@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -26,14 +26,15 @@ import org.kie.workbench.common.forms.model.FormDefinition;
  */
 public interface BackendFormRenderingContextManager extends Serializable {
 
-    BackendFormRenderingContext registerContext( FormDefinition rootForm,
-                                                 Map<String, Object> formData,
-                                                 ClassLoader classLoader,
-                                                 FormDefinition... nestedForms );
+    BackendFormRenderingContext registerContext(FormDefinition rootForm,
+                                                Map<String, Object> formData,
+                                                ClassLoader classLoader,
+                                                FormDefinition... nestedForms);
 
-    BackendFormRenderingContext updateContextData( long timestamp, Map<String, Object> formValues );
+    BackendFormRenderingContext updateContextData(long timestamp,
+                                                  Map<String, Object> formValues);
 
-    BackendFormRenderingContext getContext( Long timestamp );
+    BackendFormRenderingContext getContext(Long timestamp);
 
-    boolean removeContext( Long timestamp );
+    boolean removeContext(Long timestamp);
 }
