@@ -1,11 +1,11 @@
 /*
- * Copyright 2015 JBoss Inc
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,18 +23,16 @@ import org.jboss.errai.ioc.client.container.IOC;
 import org.jboss.errai.ioc.client.container.SyncBeanDef;
 import org.kie.workbench.common.forms.fields.shared.AbstractFieldManager;
 import org.kie.workbench.common.forms.fields.shared.FieldProvider;
-import org.kie.workbench.common.forms.model.FieldDefinition;
-import org.kie.workbench.common.forms.model.FieldType;
 
 @ApplicationScoped
 public class ClientFieldManagerImpl extends AbstractFieldManager {
 
     @PostConstruct
     protected void init() {
-        Collection<SyncBeanDef<FieldProvider>> providers = IOC.getBeanManager().lookupBeans( FieldProvider.class );
+        Collection<SyncBeanDef<FieldProvider>> providers = IOC.getBeanManager().lookupBeans(FieldProvider.class);
 
-        for ( SyncBeanDef<FieldProvider> provider : providers ) {
-            registerFieldProvider( provider.newInstance() );
+        for (SyncBeanDef<FieldProvider> provider : providers) {
+            registerFieldProvider(provider.newInstance());
         }
     }
 }
