@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *        http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -466,7 +466,9 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                 Map<String, Object> elementContext = new HashMap<>();
 
                 boolean isList = false;
-                boolean isEnum = false;
+
+                org.kie.workbench.common.forms.model.TypeKind typeKind = org.kie.workbench.common.forms.model.TypeKind.BASE;
+
                 boolean overrideI18nLabel = false;
 
                 TypeMirror finalType = fieldInfo.fieldElement.asType();
@@ -512,7 +514,7 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                         } else {
                             FormDefinition formDefinitionAnnotation = finalTypeElement.getAnnotation(FormDefinition.class);
 
-                            if ( formDefinitionAnnotation != null ) {
+                            if (formDefinitionAnnotation != null) {
                                 Collection<FieldInfo> labelInfos = extractFieldInfos((TypeElement) finalTypeElement,
                                                                                      fieldElement -> fieldElement.getAnnotation(FieldLabel.class) != null);
 
@@ -521,6 +523,7 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                                     fieldLabel = finalType.toString() + i18nSettings.separator() + labelInfo.fieldElement.getSimpleName();
                                     overrideI18nLabel = true;
                                 }
+                                typeKind = org.kie.workbench.common.forms.model.TypeKind.OBJECT;
                             }
                         }
                     }
@@ -534,8 +537,9 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                         }
                         isList = true;
                         finalType = fieldType.getTypeArguments().get(0);
-                    } else {
-                        isEnum = elementUtils.getTypeElement(finalType.toString()).getSuperclass().toString().startsWith("java.lang.Enum");
+                        typeKind = org.kie.workbench.common.forms.model.TypeKind.OBJECT;
+                    } else if(elementUtils.getTypeElement(finalType.toString()).getSuperclass().toString().startsWith("java.lang.Enum")){
+                        typeKind = org.kie.workbench.common.forms.model.TypeKind.ENUM;
                     }
                 }
 
@@ -547,12 +551,12 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                                    fieldName);
                 elementContext.put("binding",
                                    binding);
+                elementContext.put("type",
+                                   typeKind.toString());
                 elementContext.put("className",
                                    finalType.toString());
                 elementContext.put("isList",
                                    String.valueOf(isList));
-                elementContext.put("isEnum",
-                                   String.valueOf(isEnum));
                 elementContext.put("fieldModifier",
                                    fieldModifier);
 
@@ -612,8 +616,8 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
                                        "1");
                 }
 
-                if ( !overrideI18nLabel ) {
-                    if ( !StringUtils.isEmpty(i18nSettings.keyPreffix())) {
+                if (!overrideI18nLabel) {
+                    if (!StringUtils.isEmpty(i18nSettings.keyPreffix())) {
                         fieldLabel = i18nSettings.keyPreffix() + i18nSettings.separator() + fieldLabel;
                     }
                 }
@@ -645,8 +649,6 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
         return elementsSettings;
     }
 
-
-
     protected void extractFieldExtraSettings(Map<String, Object> fieldContext,
                                              VariableElement fieldElement) {
         SelectorDataProvider selectorDataProvider = fieldElement.getAnnotation(SelectorDataProvider.class);
@@ -668,7 +670,7 @@ public class FormDefinitionsProcessor extends AbstractErrorAbsorbingProcessor {
         // The stream returned by 'getResourceAsStream(templateName)' was sometimes already closed (!) and as the
         // Template class tried to read from the stream it resulted in IOException. Changing the code to
         // 'getResource(templateName).openStream()' seems to be a sensible workaround
-        try(InputStream templateIs = this.getClass().getResource(templateName).openStream()) {
+        try (InputStream templateIs = this.getClass().getResource(templateName).openStream()) {
             Configuration config = new Configuration();
 
             Template template = new Template("",
