@@ -1,11 +1,11 @@
 /*
- * Copyright 2016 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,7 +16,6 @@
 
 package org.kie.workbench.common.forms.editor.client.editor.properties;
 
-import java.util.Collection;
 import java.util.List;
 
 import org.kie.workbench.common.forms.dynamic.service.shared.FormRenderingContext;
@@ -31,13 +30,17 @@ public interface FieldPropertiesRendererHelper {
 
     List<String> getAvailableModelFields();
 
-    Collection<String> getCompatibleFieldTypes();
+    List<String> getCompatibleFieldTypes(FieldDefinition fieldDefinition);
 
     void onClose();
 
-    void onFieldTypeChange(String newType);
+    void onPressOk(FieldDefinition fieldCopy);
 
-    void onFieldBindingChange(String newBinding);
+    FieldDefinition onFieldTypeChange(FieldDefinition field,
+                                      String newType);
+
+    FieldDefinition onFieldBindingChange(FieldDefinition field,
+                                         String newBinding);
 
     Path getPath();
 }
