@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,8 +18,13 @@ package org.kie.workbench.common.forms.editor.client.editor.properties.binding;
 
 import org.jboss.errai.common.client.api.IsElement;
 import org.kie.workbench.common.forms.editor.client.editor.properties.FieldPropertiesRendererHelper;
+import org.uberfire.mvp.Command;
 
 public interface DataBindingEditor extends IsElement {
 
-    void init(FieldPropertiesRendererHelper helper);
+    void init(FieldPropertiesRendererHelper helper,
+              String binding,
+              Command onChangeCallback);
+
+    String getBinding();
 }
