@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,10 +16,21 @@
 
 package org.kie.workbench.common.forms.jbpm.client;
 
+import javax.annotation.PostConstruct;
+
 import org.jboss.errai.ioc.client.api.EntryPoint;
 import org.jboss.errai.ui.shared.api.annotations.Bundle;
+import org.kie.workbench.common.forms.jbpm.model.authoring.document.type.DocumentFieldType;
+import org.kie.workbench.common.forms.model.util.ModelPropertiesUtil;
 
 @EntryPoint
 @Bundle("resources/i18n/Constants.properties")
 public class FormsJBPMIntegrationEntryPoint {
+
+    @PostConstruct
+    public void init() {
+        // registering Document Types to ModelPropertiesUtil
+        ModelPropertiesUtil.registerBaseType(DocumentFieldType.DOCUMENT_TYPE);
+        ModelPropertiesUtil.registerBaseType(DocumentFieldType.DOCUMENT_IMPL_TYPE);
+    }
 }
