@@ -160,8 +160,10 @@ public class LibraryServiceImplTest {
         projectsMock.add(mock(Project.class));
         projectsMock.add(mock(Project.class));
 
+        final LibraryRepositoryPreferences repositoryPreferences = spy(new LibraryRepositoryPreferences());
+        doReturn("myrepo").when(repositoryPreferences).getName();
         when(preferences.getOrganizationalUnitPreferences()).thenReturn(spy(new LibraryOrganizationalUnitPreferences()));
-        when(preferences.getRepositoryPreferences()).thenReturn(spy(new LibraryRepositoryPreferences()));
+        when(preferences.getRepositoryPreferences()).thenReturn(repositoryPreferences);
         when(preferences.getProjectPreferences()).thenReturn(spy(new LibraryProjectPreferences()));
 
         libraryService = spy(new LibraryServiceImpl(ouService,
@@ -201,6 +203,7 @@ public class LibraryServiceImplTest {
         final Repository repository2 = getRepository("repository2");
         final Repository repository3 = getRepository("repository3");
         final Repository repository4 = getRepository("organizationalUnit4-repository1");
+        final Repository repository5 = getRepository("organizationalUnit3-repository1");
 
         final OrganizationalUnit organizationalUnit1 = getOrganizationalUnit("organizationalUnit1",
                                                                              repository1);
@@ -227,10 +230,19 @@ public class LibraryServiceImplTest {
         organizationalUnitWithNoRepositoriesCreatesTheSecondaryRepositorySincePrimaryAlreadyExists(organizationalUnit3,
                                                                                                    "organizationalUnit3-repository1",
                                                                                                    repository1);
+        organizationalUnitWithNoRepositoriesCreatesATertiaryRepositorySincePrimaryAndSecondaryAlreadyExists(organizationalUnit3,
+                                                                                                            "organizationalUnit3-repository1-2",
+                                                                                                            repository1,
+                                                                                                            repository5);
         organizationalUnitWithSecondaryRepositoryExistent(organizationalUnit4,
                                                           "organizationalUnit4-repository1");
     }
 
+    @Test
+    public void getOrganizationalUnitRepositoryInfoForNullOrganizationalUnitTest() {
+        assertNull(libraryService.getOrganizationalUnitRepositoryInfo(null));
+    }
+
     @Test
     public void getLibraryInfoTest() {
         final Repository repository = mock(Repository.class);
@@ -254,14 +266,17 @@ public class LibraryServiceImplTest {
         when(preferences.getRepositoryPreferences().getName()).thenReturn("repo-alias");
         when(preferences.getOrganizationalUnitPreferences().getAliasInSingular()).thenReturn("team");
         when(preferences.getProjectPreferences().getBranch()).thenReturn("master");
-        when(preferences.getProjectPreferences().getGroupId()).thenReturn("projectGroupID");
         when(preferences.getProjectPreferences().getVersion()).thenReturn("1.0");
 
+        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
+        when(organizationalUnit.getDefaultGroupId()).thenReturn("ouGroupID");
+
         final Repository repository = mock(Repository.class);
         final Path projectRootPath = mock(Path.class);
         when(repository.getRoot()).thenReturn(projectRootPath);
 
         libraryService.createProject("Project Name",
+                                     organizationalUnit,
                                      repository,
                                      "baseURL",
                                      "description");
@@ -272,6 +287,8 @@ public class LibraryServiceImplTest {
                                              any());
 
         final POM pom = pomArgumentCaptor.getValue();
+        assertEquals("ouGroupID",
+                     pom.getGav().getGroupId());
         assertEquals("ProjectName",
                      pom.getGav().getArtifactId());
         assertEquals("description",
@@ -316,11 +333,12 @@ public class LibraryServiceImplTest {
 
     @Test
     public void emptyFirstPage() throws Exception {
-
         final Project project = mock(Project.class);
         final Path path = mock(Path.class);
         when(project.getRootPath()).thenReturn(path);
-        when(path.toURI()).thenReturn("a/b/c");
+        when(path.toURI()).thenReturn("file://a/b/c");
+
+        doReturn(true).when(ioService).exists(any());
 
         final ProjectAssetsQuery query = new ProjectAssetsQuery(project,
                                                                 "",
@@ -342,7 +360,7 @@ public class LibraryServiceImplTest {
         assertEquals(1,
                      pageRequest.getQueryTerms().size());
 
-        assertEquals("a/b/c",
+        assertEquals("file://a/b/c",
                      pageRequest.getQueryTerms().iterator().next().getValue());
 
         assertEquals(0,
@@ -354,11 +372,13 @@ public class LibraryServiceImplTest {
     @Test
     public void queryWithAFilter() throws Exception {
 
-        final Path path = mockPath("the_project");
+        final Path path = mockPath("file://the_project");
 
         final Project project = mock(Project.class);
         when(project.getRootPath()).thenReturn(path);
 
+        doReturn(true).when(ioService).exists(any());
+
         final ProjectAssetsQuery query = new ProjectAssetsQuery(project,
                                                                 "helloo",
                                                                 10,
@@ -380,7 +400,7 @@ public class LibraryServiceImplTest {
                      pageRequest.getQueryTerms().size());
 
         assertQueryTermsContains(pageRequest.getQueryTerms(),
-                                 "the_project");
+                                 "file://the_project");
         assertQueryTermsContains(pageRequest.getQueryTerms(),
                                  "*helloo*");
 
@@ -431,8 +451,7 @@ public class LibraryServiceImplTest {
 
     private void assertQueryTermsContains(final Set<ValueIndexTerm> terms,
                                           final String value) {
-        assertTrue("Trying to find term " + value,
-                   terms.stream().filter((t) -> t.getValue().equals(value)).findFirst().isPresent());
+        assertTrue(terms.stream().filter((t) -> t.getValue().equals(value)).findFirst().isPresent());
     }
 
     @Test
@@ -555,12 +574,15 @@ public class LibraryServiceImplTest {
 
     @Test
     public void createPOM() {
-        when(preferences.getProjectPreferences().getGroupId()).thenReturn("projectGroupID");
+        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
+        when(organizationalUnit.getDefaultGroupId()).thenReturn("ouGroupID");
+
         when(preferences.getProjectPreferences().getVersion()).thenReturn("1.0");
         when(preferences.getProjectPreferences().getDescription()).thenReturn("desc");
 
         GAV gav = libraryService.createGAV("proj",
-                                           preferences);
+                                           preferences,
+                                           organizationalUnit);
         POM proj = libraryService.createPOM("proj",
                                             "description",
                                             gav);
@@ -575,13 +597,16 @@ public class LibraryServiceImplTest {
 
     @Test
     public void createGAV() {
-        when(preferences.getProjectPreferences().getGroupId()).thenReturn("projectGroupID");
+        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
+        when(organizationalUnit.getDefaultGroupId()).thenReturn("ouGroupID");
+
         when(preferences.getProjectPreferences().getVersion()).thenReturn("1.0");
 
         GAV gav = libraryService.createGAV("proj",
-                                           preferences);
+                                           preferences,
+                                           organizationalUnit);
 
-        assertEquals(preferences.getProjectPreferences().getGroupId(),
+        assertEquals(organizationalUnit.getDefaultGroupId(),
                      gav.getGroupId());
         assertEquals("proj",
                      gav.getArtifactId());
@@ -589,6 +614,14 @@ public class LibraryServiceImplTest {
                      gav.getVersion());
     }
 
+    @Test
+    public void getSecondaryDefaultRepositoryNameTest() {
+        assertEquals("myalias-myrepo",
+                     libraryService.getSecondaryDefaultRepositoryName(getOrganizationalUnit("myalias")));
+        assertEquals("my-alias-myrepo",
+                     libraryService.getSecondaryDefaultRepositoryName(getOrganizationalUnit("my alias")));
+    }
+
     private void organizationalUnitWithSecondaryRepositoryExistent(final OrganizationalUnit organizationalUnit,
                                                                    final String repositoryIdentifier) {
         final OrganizationalUnitRepositoryInfo info5 = libraryService.getOrganizationalUnitRepositoryInfo(organizationalUnit);
@@ -611,6 +644,21 @@ public class LibraryServiceImplTest {
                                                repositoryIdentifier);
     }
 
+    private void organizationalUnitWithNoRepositoriesCreatesATertiaryRepositorySincePrimaryAndSecondaryAlreadyExists(final OrganizationalUnit organizationalUnit,
+                                                                                                                     final String repositoryIdentifier,
+                                                                                                                     final Repository alreadyExistentPrimaryRepository,
+                                                                                                                     final Repository alreadyExistentSecondaryRepository) {
+        doReturn(alreadyExistentPrimaryRepository).when(repositoryService).getRepository("repository1");
+        doReturn(alreadyExistentSecondaryRepository).when(repositoryService).getRepository("organizationalUnit3-repository1");
+
+        final OrganizationalUnitRepositoryInfo info = libraryService.getOrganizationalUnitRepositoryInfo(organizationalUnit);
+        assertOrganizationalUnitRepositoryInfo(info,
+                                               4,
+                                               organizationalUnit.getIdentifier(),
+                                               0,
+                                               repositoryIdentifier);
+    }
+
     private void organizationalUnitWithNoRepositoriesCreatesThePrimaryRepository(final OrganizationalUnit organizationalUnit,
                                                                                  final String repositoryIdentifier) {
         doReturn(null).when(repositoryService).getRepository("repository1");
