@@ -28,6 +28,7 @@ import javax.inject.Inject;
 import org.ext.uberfire.social.activities.model.ExtendedTypes;
 import org.ext.uberfire.social.activities.model.SocialFileSelectedEvent;
 import org.guvnor.asset.management.social.AssetManagementEventTypes;
+import org.guvnor.common.services.project.client.preferences.ProjectScopedResolutionStrategySupplier;
 import org.guvnor.common.services.project.context.ProjectContext;
 import org.guvnor.common.services.project.context.ProjectContextChangeEvent;
 import org.guvnor.common.services.project.events.DeleteProjectEvent;
@@ -47,9 +48,10 @@ import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectInfo;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
 import org.kie.workbench.common.screens.library.client.events.ProjectDetailEvent;
+import org.kie.workbench.common.screens.library.client.events.ProjectMetricsEvent;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
 import org.kie.workbench.common.screens.library.client.resources.i18n.LibraryConstants;
-import org.kie.workbench.common.screens.library.client.widgets.LibraryToolbarPresenter;
+import org.kie.workbench.common.screens.library.client.widgets.library.LibraryToolbarPresenter;
 import org.kie.workbench.common.widgets.client.handlers.NewResourceSuccessEvent;
 import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -59,12 +61,17 @@ import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
 import org.uberfire.ext.editor.commons.client.event.ConcurrentRenameAcceptedEvent;
+import org.uberfire.ext.preferences.client.central.screen.PreferencesRootScreen;
+import org.uberfire.ext.preferences.client.event.PreferencesCentralInitializationEvent;
+import org.uberfire.ext.preferences.client.event.PreferencesCentralSaveEvent;
+import org.uberfire.ext.preferences.client.event.PreferencesCentralUndoChangesEvent;
 import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.ConditionalPlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
+import org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.impl.PartDefinitionImpl;
 
@@ -78,6 +85,8 @@ public class LibraryPlaces {
     public static final String EMPTY_PROJECT_SCREEN = "EmptyProjectScreen";
     public static final String PROJECT_SCREEN = "ProjectScreen";
     public static final String PROJECT_DETAIL_SCREEN = "ProjectsDetailScreen";
+    public static final String ORG_UNITS_METRICS_SCREEN = "OrgUnitsMetricsScreen";
+    public static final String PROJECT_METRICS_SCREEN = "ProjectMetricsScreen";
     public static final String ORGANIZATIONAL_UNITS_SCREEN = "LibraryOrganizationalUnitsScreen";
     public static final String PROJECT_SETTINGS = "projectScreen";
     public static final String PROJECT_EXPLORER = "org.kie.guvnor.explorer";
@@ -89,11 +98,13 @@ public class LibraryPlaces {
         add(EMPTY_LIBRARY_SCREEN);
         add(LIBRARY_SCREEN);
         add(EMPTY_PROJECT_SCREEN);
+        add(ORG_UNITS_METRICS_SCREEN);
         add(PROJECT_SCREEN);
+        add(PROJECT_METRICS_SCREEN);
         add(PROJECT_DETAIL_SCREEN);
         add(ORGANIZATIONAL_UNITS_SCREEN);
         add(PROJECT_SETTINGS);
-        add(MESSAGES);
+        add(PreferencesRootScreen.IDENTIFIER);
     }});
 
     private UberfireBreadcrumbs breadcrumbs;
@@ -102,6 +113,8 @@ public class LibraryPlaces {
 
     private Event<ProjectDetailEvent> projectDetailEvent;
 
+    private Event<ProjectMetricsEvent> projectMetricsEvent;
+
     private Event<AssetDetailEvent> assetDetailEvent;
 
     private ResourceUtils resourceUtils;
@@ -132,6 +145,10 @@ public class LibraryPlaces {
 
     private Caller<ExplorerService> explorerService;
 
+    private ProjectScopedResolutionStrategySupplier projectScopedResolutionStrategySupplier;
+
+    private Event<PreferencesCentralInitializationEvent> preferencesCentralInitializationEvent;
+
     private boolean docksReady = false;
 
     private boolean docksHidden = true;
@@ -144,6 +161,7 @@ public class LibraryPlaces {
     public LibraryPlaces(final UberfireBreadcrumbs breadcrumbs,
                          final TranslationService ts,
                          final Event<ProjectDetailEvent> projectDetailEvent,
+                         final Event<ProjectMetricsEvent> projectMetricsEvent,
                          final Event<AssetDetailEvent> assetDetailEvent,
                          final ResourceUtils resourceUtils,
                          final Caller<LibraryService> libraryService,
@@ -158,10 +176,13 @@ public class LibraryPlaces {
                          final ManagedInstance<ExamplesWizard> examplesWizards,
                          final TranslationUtils translationUtils,
                          final Caller<VFSService> vfsService,
-                         final Caller<ExplorerService> explorerService) {
+                         final Caller<ExplorerService> explorerService,
+                         final ProjectScopedResolutionStrategySupplier projectScopedResolutionStrategySupplier,
+                         final Event<PreferencesCentralInitializationEvent> preferencesCentralInitializationEvent) {
         this.breadcrumbs = breadcrumbs;
         this.ts = ts;
         this.projectDetailEvent = projectDetailEvent;
+        this.projectMetricsEvent = projectMetricsEvent;
         this.assetDetailEvent = assetDetailEvent;
         this.resourceUtils = resourceUtils;
         this.libraryService = libraryService;
@@ -177,6 +198,8 @@ public class LibraryPlaces {
         this.translationUtils = translationUtils;
         this.vfsService = vfsService;
         this.explorerService = explorerService;
+        this.projectScopedResolutionStrategySupplier = projectScopedResolutionStrategySupplier;
+        this.preferencesCentralInitializationEvent = preferencesCentralInitializationEvent;
     }
 
     public ProjectInfo getProjectInfo() {
@@ -257,6 +280,7 @@ public class LibraryPlaces {
     public void projectDeleted(@Observes final DeleteProjectEvent deleteProjectEvent) {
         if (isLibraryPerspectiveOpen()) {
             if (deleteProjectEvent.getProject().equals(lastViewedProject)) {
+                closeAllPlaces();
                 goToLibrary();
                 notificationEvent.fire(new NotificationEvent(ts.getTranslation(LibraryConstants.ProjectDeleted),
                                                              NotificationEvent.NotificationType.DEFAULT));
@@ -313,6 +337,18 @@ public class LibraryPlaces {
                 || placeManager.getStatus(getLibraryPlaceRequestWithoutRefresh()).equals(PlaceStatus.OPEN);
     }
 
+    public void onPreferencesSave(@Observes PreferencesCentralSaveEvent event) {
+        if (isLibraryPerspectiveOpen()) {
+            goToProject(getProjectInfo());
+        }
+    }
+
+    public void onPreferencesCancel(@Observes PreferencesCentralUndoChangesEvent event) {
+        if (isLibraryPerspectiveOpen()) {
+            goToProject(getProjectInfo());
+        }
+    }
+
     public void onSocialFileSelected(@Observes final SocialFileSelectedEvent event) {
         vfsService.call(new RemoteCallback<Path>() {
             @Override
@@ -342,7 +378,7 @@ public class LibraryPlaces {
         } else if (isProjectEvent(eventType)) {
             placeManager.goTo(libraryPerspective);
             goToProject(projectInfo);
-        } else if (path != null){
+        } else if (path != null) {
             placeManager.goTo(libraryPerspective);
             goToProject(projectInfo,
                         true,
@@ -426,6 +462,32 @@ public class LibraryPlaces {
                                   () -> goToProject(projectInfo));
     }
 
+    public void setupLibraryBreadCrumbsForProjectMetrics(final ProjectInfo projectInfo) {
+        breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  translationUtils.getOrganizationalUnitAliasInPlural(),
+                                  () -> goToOrganizationalUnits());
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  getSelectedOrganizationalUnit().getName(),
+                                  () -> goToLibrary());
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  projectInfo.getProject().getProjectName(),
+                                  () -> goToProject(projectInfo));
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  translationUtils.getProjectMetrics(),
+                                  () -> goToProjectMetrics(projectInfo));
+    }
+
+    public void setupLibraryBreadCrumbsForOrgUnitsMetrics() {
+        breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  translationUtils.getOrganizationalUnitAliasInPlural(),
+                                  () -> goToOrganizationalUnits());
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  translationUtils.getOrgUnitsMetrics(),
+                                  () -> goToOrgUnitsMetrics());
+    }
+
     public void setupLibraryBreadCrumbsForAsset(final ProjectInfo projectInfo,
                                                 final Path path) {
         String assetName;
@@ -451,7 +513,24 @@ public class LibraryPlaces {
                                                   path));
     }
 
+    public void setupLibraryBreadCrumbsForPreferences(final ProjectInfo projectInfo) {
+        breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  translationUtils.getOrganizationalUnitAliasInPlural(),
+                                  () -> goToOrganizationalUnits());
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  getSelectedOrganizationalUnit().getName(),
+                                  () -> goToLibrary());
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  projectInfo.getProject().getProjectName(),
+                                  () -> goToProject(projectInfo));
+        breadcrumbs.addBreadCrumb(LibraryPlaces.LIBRARY_PERSPECTIVE,
+                                  ts.getTranslation(LibraryConstants.Preferences),
+                                  () -> goToPreferences());
+    }
+
     public void refresh(final Command callback) {
+        breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
         translationUtils.refresh(() -> {
             libraryToolbar.init(() -> {
                 setupToolBar();
@@ -539,6 +618,7 @@ public class LibraryPlaces {
             }
 
             if (goToProject) {
+                closeLibraryPlaces();
                 hideDocks();
                 lastViewedProject = projectInfo.getProject();
                 if (fireProjectContextChangeEvent) {
@@ -561,6 +641,25 @@ public class LibraryPlaces {
         }).hasAssets(projectInfo.getProject());
     }
 
+    public void goToOrgUnitsMetrics() {
+        final PlaceRequest metricsScreen = new DefaultPlaceRequest(LibraryPlaces.ORG_UNITS_METRICS_SCREEN);
+        final PartDefinitionImpl part = new PartDefinitionImpl(metricsScreen);
+        part.setSelectable(false);
+        placeManager.goTo(part,
+                          libraryPerspective.getRootPanel());
+        setupLibraryBreadCrumbsForOrgUnitsMetrics();
+    }
+
+    public void goToProjectMetrics(final ProjectInfo projectInfo) {
+        final PlaceRequest metricsScreen = new DefaultPlaceRequest(LibraryPlaces.PROJECT_METRICS_SCREEN);
+        final PartDefinitionImpl part = new PartDefinitionImpl(metricsScreen);
+        part.setSelectable(false);
+        placeManager.goTo(part,
+                          libraryPerspective.getRootPanel());
+        setupLibraryBreadCrumbsForProjectMetrics(projectInfo);
+        projectMetricsEvent.fire(new ProjectMetricsEvent(projectInfo));
+    }
+
     public void goToAsset(final ProjectInfo projectInfo,
                           final Path path) {
         final PlaceRequest placeRequest = generatePlaceRequest(path);
@@ -603,6 +702,22 @@ public class LibraryPlaces {
         placeManager.goTo(MESSAGES);
     }
 
+    public void goToPreferences() {
+        final PreferenceScopeResolutionStrategyInfo customScopeResolutionStrategy = projectScopedResolutionStrategySupplier.get();
+        final PreferencesCentralInitializationEvent initEvent = new PreferencesCentralInitializationEvent("ProjectPreferences",
+                                                                                                          customScopeResolutionStrategy,
+                                                                                                          null);
+
+        final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(PreferencesRootScreen.IDENTIFIER);
+        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
+        part.setSelectable(false);
+        placeManager.goTo(part,
+                          libraryPerspective.getRootPanel());
+
+        preferencesCentralInitializationEvent.fire(initEvent);
+        setupLibraryBreadCrumbsForPreferences(getProjectInfo());
+    }
+
     public OrganizationalUnit getSelectedOrganizationalUnit() {
         return projectContext.getActiveOrganizationalUnit();
     }
@@ -640,4 +755,10 @@ public class LibraryPlaces {
 
         return placesClosed;
     }
+
+    void closeAllPlaces() {
+        closingLibraryPlaces = true;
+        placeManager.closeAllPlaces();
+        closingLibraryPlaces = false;
+    }
 }
