@@ -20,6 +20,7 @@ import javax.enterprise.event.Event;
 
 import org.ext.uberfire.social.activities.model.ExtendedTypes;
 import org.ext.uberfire.social.activities.model.SocialFileSelectedEvent;
+import org.guvnor.common.services.project.client.preferences.ProjectScopedResolutionStrategySupplier;
 import org.guvnor.common.services.project.context.ProjectContext;
 import org.guvnor.common.services.project.context.ProjectContextChangeEvent;
 import org.guvnor.common.services.project.events.DeleteProjectEvent;
@@ -41,8 +42,9 @@ import org.kie.workbench.common.screens.library.api.LibraryService;
 import org.kie.workbench.common.screens.library.api.ProjectInfo;
 import org.kie.workbench.common.screens.library.client.events.AssetDetailEvent;
 import org.kie.workbench.common.screens.library.client.events.ProjectDetailEvent;
+import org.kie.workbench.common.screens.library.client.events.ProjectMetricsEvent;
 import org.kie.workbench.common.screens.library.client.perspective.LibraryPerspective;
-import org.kie.workbench.common.screens.library.client.widgets.LibraryToolbarPresenter;
+import org.kie.workbench.common.screens.library.client.widgets.library.LibraryToolbarPresenter;
 import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.mockito.Mock;
 import org.mockito.Mockito;
@@ -53,12 +55,17 @@ import org.uberfire.backend.vfs.VFSService;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
+import org.uberfire.ext.preferences.client.central.screen.PreferencesRootScreen;
+import org.uberfire.ext.preferences.client.event.PreferencesCentralInitializationEvent;
+import org.uberfire.ext.preferences.client.event.PreferencesCentralSaveEvent;
+import org.uberfire.ext.preferences.client.event.PreferencesCentralUndoChangesEvent;
 import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.mocks.CallerMock;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.ConditionalPlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.mvp.impl.PathPlaceRequest;
+import org.uberfire.preferences.shared.impl.PreferenceScopeResolutionStrategyInfo;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.PanelDefinition;
 import org.uberfire.workbench.model.impl.PartDefinitionImpl;
@@ -77,6 +84,9 @@ public class LibraryPlacesTest {
     @Mock
     private Event<ProjectDetailEvent> projectDetailEvent;
 
+    @Mock
+    private Event<ProjectMetricsEvent> projectMetricsEvent;
+
     @Mock
     private Event<AssetDetailEvent> assetDetailEvent;
 
@@ -125,6 +135,12 @@ public class LibraryPlacesTest {
     private ExplorerService explorerService;
     private Caller<ExplorerService> explorerServiceCaller;
 
+    @Mock
+    private ProjectScopedResolutionStrategySupplier projectScopedResolutionStrategySupplier;
+
+    @Mock
+    private Event<PreferencesCentralInitializationEvent> preferencesCentralInitializationEvent;
+
     private LibraryPlaces libraryPlaces;
 
     private OrganizationalUnit activeOrganizationalUnit;
@@ -143,6 +159,7 @@ public class LibraryPlacesTest {
         libraryPlaces = spy(new LibraryPlaces(breadcrumbs,
                                               ts,
                                               projectDetailEvent,
+                                              projectMetricsEvent,
                                               assetDetailEvent,
                                               resourceUtils,
                                               libraryServiceCaller,
@@ -157,7 +174,9 @@ public class LibraryPlacesTest {
                                               examplesWizards,
                                               translationUtils,
                                               vfsServiceCaller,
-                                              explorerServiceCaller));
+                                              explorerServiceCaller,
+                                              projectScopedResolutionStrategySupplier,
+                                              preferencesCentralInitializationEvent));
 
         activeOrganizationalUnit = mock(OrganizationalUnit.class);
         activeRepository = mock(Repository.class);
@@ -375,6 +394,48 @@ public class LibraryPlacesTest {
                                           false);
     }
 
+    @Test
+    public void onPreferencesSaveTest() {
+        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        doNothing().when(libraryPlaces).goToProject(any());
+
+        libraryPlaces.onPreferencesSave(mock(PreferencesCentralSaveEvent.class));
+
+        verify(libraryPlaces).goToProject(libraryPlaces.getProjectInfo());
+    }
+
+    @Test
+    public void onPreferencesSaveOutsideLibraryTest() {
+        doReturn(PlaceStatus.CLOSE).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        doReturn(PlaceStatus.CLOSE).when(placeManager).getStatus(any(PlaceRequest.class));
+
+        libraryPlaces.onPreferencesSave(mock(PreferencesCentralSaveEvent.class));
+
+        verify(libraryPlaces,
+               never()).goToProject(any());
+    }
+
+    @Test
+    public void onPreferencesCancelTest() {
+        doReturn(PlaceStatus.OPEN).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        doNothing().when(libraryPlaces).goToProject(any());
+
+        libraryPlaces.onPreferencesCancel(mock(PreferencesCentralUndoChangesEvent.class));
+
+        verify(libraryPlaces).goToProject(libraryPlaces.getProjectInfo());
+    }
+
+    @Test
+    public void onPreferencesCancelOutsideLibraryTest() {
+        doReturn(PlaceStatus.CLOSE).when(placeManager).getStatus(LibraryPlaces.LIBRARY_PERSPECTIVE);
+        doReturn(PlaceStatus.CLOSE).when(placeManager).getStatus(any(PlaceRequest.class));
+
+        libraryPlaces.onPreferencesCancel(mock(PreferencesCentralUndoChangesEvent.class));
+
+        verify(libraryPlaces,
+               never()).goToProject(any());
+    }
+
     @Test
     public void goToOrganizationalUnitsTest() {
         final PlaceRequest placeRequest = new DefaultPlaceRequest(LibraryPlaces.ORGANIZATIONAL_UNITS_SCREEN);
@@ -460,12 +521,57 @@ public class LibraryPlacesTest {
 
         verify(placeManager).goTo(eq(part),
                                   any(PanelDefinition.class));
+        verify(libraryPlaces).closeLibraryPlaces();
         verify(projectDetailEvent).fire(any(ProjectDetailEvent.class));
         verify(projectContextChangeEvent).fire(any(ProjectContextChangeEvent.class));
         verify(libraryPlaces).setupLibraryBreadCrumbsForProject(projectInfo);
         verify(placeManager).closeAllPlacesOrNothing();
     }
 
+    @Test
+    public void goToOrgUnitsMetricsTest() {
+        final PlaceRequest metricsScreen = new DefaultPlaceRequest(LibraryPlaces.ORG_UNITS_METRICS_SCREEN);
+        final PartDefinitionImpl part = new PartDefinitionImpl(metricsScreen);
+        part.setSelectable(false);
+
+        libraryPlaces.goToOrgUnitsMetrics();
+
+        verify(placeManager).goTo(eq(part), any(PanelDefinition.class));
+        verify(libraryPlaces).setupLibraryBreadCrumbsForOrgUnitsMetrics();
+    }
+
+    @Test
+    public void goToProjectMetricsTest() {
+        final PlaceRequest projectScreen = new DefaultPlaceRequest(LibraryPlaces.PROJECT_METRICS_SCREEN);
+        final PartDefinitionImpl part = new PartDefinitionImpl(projectScreen);
+        part.setSelectable(false);
+        final ProjectInfo projectInfo = new ProjectInfo(activeOrganizationalUnit,
+                                                        activeRepository,
+                                                        activeBranch,
+                                                        activeProject);
+
+        libraryPlaces.goToProjectMetrics(projectInfo);
+
+        verify(placeManager).goTo(eq(part), any(PanelDefinition.class));
+        verify(projectMetricsEvent).fire(any(ProjectMetricsEvent.class));
+        verify(libraryPlaces).setupLibraryBreadCrumbsForProjectMetrics(projectInfo);
+    }
+
+    @Test
+    public void closeLibraryPlacesTest() {
+        libraryPlaces.closeLibraryPlaces();
+        verify(placeManager).closePlace(LibraryPlaces.NEW_PROJECT_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.EMPTY_LIBRARY_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.LIBRARY_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.EMPTY_PROJECT_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.PROJECT_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.PROJECT_METRICS_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.PROJECT_DETAIL_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.ORGANIZATIONAL_UNITS_SCREEN);
+        verify(placeManager).closePlace(LibraryPlaces.PROJECT_SETTINGS);
+        verify(placeManager).closePlace(PreferencesRootScreen.IDENTIFIER);
+
+    }
     @Test
     public void goToSameProjectTest() {
         final ProjectInfo projectInfo = new ProjectInfo(activeOrganizationalUnit,
@@ -498,6 +604,25 @@ public class LibraryPlacesTest {
         verify(placeManager).goTo(LibraryPlaces.MESSAGES);
     }
 
+    @Test
+    public void goToPreferencesTest() {
+        final PreferenceScopeResolutionStrategyInfo scopeResolutionStrategyInfo = mock(PreferenceScopeResolutionStrategyInfo.class);
+        doReturn(scopeResolutionStrategyInfo).when(projectScopedResolutionStrategySupplier).get();
+
+        final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(PreferencesRootScreen.IDENTIFIER);
+        final PartDefinitionImpl part = new PartDefinitionImpl(placeRequest);
+        part.setSelectable(false);
+
+        libraryPlaces.goToPreferences();
+
+        verify(placeManager).goTo(eq(part),
+                                  any(PanelDefinition.class));
+        verify(preferencesCentralInitializationEvent).fire(new PreferencesCentralInitializationEvent("ProjectPreferences",
+                                                                                                     scopeResolutionStrategyInfo,
+                                                                                                     null));
+        verify(libraryPlaces).setupLibraryBreadCrumbsForPreferences(any());
+    }
+
     @Test
     public void projectDeletedRedirectsToLibraryWhenItIsOpenedTest() {
         final Project activeProject = mock(Project.class);
@@ -512,6 +637,7 @@ public class LibraryPlacesTest {
                                                   activeProject));
         libraryPlaces.projectDeleted(deleteProjectEvent);
 
+        verify(libraryPlaces).closeAllPlaces();
         verify(libraryPlaces).goToLibrary();
         verify(notificationEvent).fire(any());
     }
@@ -528,6 +654,8 @@ public class LibraryPlacesTest {
 
         libraryPlaces.projectDeleted(deleteProjectEvent);
 
+        verify(libraryPlaces,
+               never()).closeAllPlaces();
         verify(libraryPlaces,
                never()).goToLibrary();
         verify(notificationEvent,
@@ -612,6 +740,7 @@ public class LibraryPlacesTest {
         libraryPlaces.onSocialFileSelected(event);
 
         verify(placeManager).goTo(libraryPerspective);
-        verify(libraryPlaces).goToAsset(any(ProjectInfo.class), any(Path.class));
+        verify(libraryPlaces).goToAsset(any(ProjectInfo.class),
+                                        any(Path.class));
     }
 }
