@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,9 +16,20 @@
 
 package org.kie.workbench.common.stunner.shapes.def;
 
-import org.kie.workbench.common.stunner.core.definition.shape.MutableShapeDef;
+import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
+import org.kie.workbench.common.stunner.core.definition.shape.ShapeDef;
 
-public interface ConnectorShapeDef<W> extends BasicShapeWithTitleDef<W>,
-                                              MutableShapeDef<W> {
+public interface ConnectorShapeDef<W> extends BasicMutableShapeDef<W> {
 
+    ConnectorGlyph GLYPH = ConnectorGlyph.create();
+
+    @Override
+    default Glyph getGlyph(Class<? extends W> type) {
+        return GLYPH;
+    }
+
+    @Override
+    default Class<? extends ShapeDef> getType() {
+        return ConnectorShapeDef.class;
+    }
 }
