@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,7 +19,7 @@ package org.kie.workbench.common.stunner.core.client.canvas.controls.builder.req
 import org.kie.workbench.common.stunner.core.client.canvas.controls.builder.BuildRequest;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.view.Magnet;
+import org.kie.workbench.common.stunner.core.graph.content.view.Connection;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
 public interface NodeBuildRequest extends BuildRequest {
@@ -28,7 +28,7 @@ public interface NodeBuildRequest extends BuildRequest {
 
     Edge<View<?>, Node> getInEdge();
 
-    Magnet getSourceMagnet();
+    Connection getSourceConnection();
 
-    Magnet getTargetMagnet();
+    Connection getTargetConnection();
 }
