@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -42,8 +42,7 @@ import org.kie.workbench.common.stunner.core.command.impl.CompositeCommandImpl;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Node;
-import org.kie.workbench.common.stunner.core.graph.content.view.Magnet;
-import org.kie.workbench.common.stunner.core.graph.content.view.MagnetImpl;
+import org.kie.workbench.common.stunner.core.graph.content.view.MagnetConnection;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.processing.index.bounds.GraphBoundsIndexer;
@@ -147,7 +146,6 @@ public abstract class AbstractElementBuilderControl extends AbstractCanvasHandle
         if (request.getX() == -1 || request.getY() == -1) {
             // TODO: Use the right size of the target element to be created.
             final double[] p = canvasLayoutUtils.getNext(canvasHandler,
-                                                         150,
                                                          75);
             x = p[0] + 50;
             y = p[1] > 0 ? p[1] : 200;
@@ -196,14 +194,6 @@ public abstract class AbstractElementBuilderControl extends AbstractCanvasHandle
         commandManagerProvider = null;
     }
 
-    public interface CommandsCallback {
-
-        void onComplete(final String uuid,
-                        final List<Command<AbstractCanvasHandler, CanvasViolation>> commands);
-
-        void onError(final ClientRuntimeError error);
-    }
-
     public void getCommands(final Object definition,
                             final Node<View<?>, Edge> parent,
                             final double x,
@@ -261,7 +251,7 @@ public abstract class AbstractElementBuilderControl extends AbstractCanvasHandle
         } else if (element instanceof Edge && null != parent) {
             command = canvasCommandFactory.addConnector(parent,
                                                         (Edge) element,
-                                                        MagnetImpl.Builder.build(Magnet.MagnetType.OUTGOING),
+                                                        MagnetConnection.Builder.forElement(parent),
                                                         getShapeSetId());
         } else {
             throw new RuntimeException("Unrecognized element type for " + element);
@@ -323,4 +313,12 @@ public abstract class AbstractElementBuilderControl extends AbstractCanvasHandle
     CanvasCommandManager<AbstractCanvasHandler> getCommandManager() {
         return commandManagerProvider.getCommandManager();
     }
+
+    public interface CommandsCallback {
+
+        void onComplete(final String uuid,
+                        final List<Command<AbstractCanvasHandler, CanvasViolation>> commands);
+
+        void onError(final ClientRuntimeError error);
+    }
 }
