@@ -1,11 +1,11 @@
 /*
- * Copyright 2016 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2017 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -34,6 +34,7 @@ import org.kie.workbench.common.stunner.core.definition.annotation.definition.Ca
 import org.kie.workbench.common.stunner.core.definition.annotation.definition.Labels;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.MorphBase;
 import org.kie.workbench.common.stunner.core.definition.builder.Builder;
+import org.kie.workbench.common.stunner.core.util.HashUtil;
 
 @MorphBase(defaultType = EndNoneEvent.class
         /* TODO: Disabled morphing from end to start events for M1
@@ -86,7 +87,7 @@ public abstract class BaseEndEvent implements BPMNDefinition,
     static abstract class BaseEndEventBuilder<T extends BaseEndEvent> implements Builder<T> {
 
         public static final String BG_COLOR = "#ff6347";
-        public static final Double BORDER_SIZE = 40d;
+        public static final Double BORDER_SIZE = 1.5d;
         public static final String BORDER_COLOR = "#000000";
         public static final Double RADIUS = 14d;
     }
@@ -183,4 +184,28 @@ public abstract class BaseEndEvent implements BPMNDefinition,
     public void setDimensionsSet(final CircleDimensionSet dimensionsSet) {
         this.dimensionsSet = dimensionsSet;
     }
+
+    @Override
+    public int hashCode() {
+        return HashUtil.combineHashCodes(general.hashCode(),
+                                         dataIOSet.hashCode(),
+                                         backgroundSet.hashCode(),
+                                         throwEventAttributes.hashCode(),
+                                         fontSet.hashCode(),
+                                         dimensionsSet.hashCode());
+    }
+
+    @Override
+    public boolean equals(Object o) {
+        if (o instanceof BaseEndEvent) {
+            BaseEndEvent other = (BaseEndEvent) o;
+            return general.equals(other.general) &&
+                    dataIOSet.equals(other.dataIOSet) &&
+                    backgroundSet.equals(other.backgroundSet) &&
+                    throwEventAttributes.equals(other.throwEventAttributes) &&
+                    fontSet.equals(other.fontSet) &&
+                    dimensionsSet.equals(other.dimensionsSet);
+        }
+        return false;
+    }
 }
