@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,11 +16,13 @@
 
 package org.kie.workbench.common.stunner.cm.client.shape;
 
+import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
+import org.kie.workbench.common.stunner.cm.client.shape.def.CaseManagementShapeDef;
 import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
 import org.kie.workbench.common.stunner.core.definition.shape.MutableShapeDef;
 import org.kie.workbench.common.stunner.shapes.client.BasicContainerShape;
 
-public class AbstractCMContainerShape<W, D extends MutableShapeDef<W>, V extends ShapeView<?>>
+public class AbstractCMContainerShape<W extends BPMNDefinition, D extends CaseManagementShapeDef<W>, V extends ShapeView<?>>
         extends BasicContainerShape<W, D, V> {
 
     private static final double ACTIVE_STROKE_WIDTH = 1d;
